@@ -507,7 +507,6 @@ as.character.ets <- function(x, ...) {
 #   list(lower=myLower, upper=myUpper)
 # }
 
-
 etsmodel <- function(y, errortype, trendtype, seasontype, damped,
                      alpha=NULL, beta=NULL, gamma=NULL, phi=NULL,
                      lower, upper, opt.crit, nmse, bounds, maxit=2000, control=NULL, seed=NULL, trace=FALSE) {
@@ -521,7 +520,6 @@ etsmodel <- function(y, errortype, trendtype, seasontype, damped,
     m <- 1
   }
 
-
   # Modify limits if alpha, beta or gamma have been specified.
   if (!is.null(alpha)) {
     upper[2] <- min(alpha, upper[2])
@@ -735,7 +733,6 @@ etsmodel <- function(y, errortype, trendtype, seasontype, damped,
   ))
 }
 
-
 etsTargetFunctionInit <- function(par, y, nstate, errortype, trendtype, seasontype, damped, par.noopt, lowerb, upperb,
                                   opt.crit, nmse, bounds, m, pnames, pnames2) {
   names(par) <- pnames
@@ -809,7 +806,6 @@ etsTargetFunctionInit <- function(par, y, nstate, errortype, trendtype, seasonty
     }
   }
 
-
   if (!damped) {
     phi <- 1
   }
@@ -844,7 +840,6 @@ etsTargetFunctionInit <- function(par, y, nstate, errortype, trendtype, seasonty
   res
 }
 
-
 initparam <- function(alpha, beta, gamma, phi, trendtype, seasontype, damped, lower, upper, m, bounds) {
   if(bounds == "admissible") {
     lower[1L:3L] <- lower[1L:3L]*0
@@ -853,7 +848,6 @@ initparam <- function(alpha, beta, gamma, phi, trendtype, seasontype, damped, lo
     stop("Inconsistent parameter boundaries")
   }
 
-
   # Select alpha
   if (is.null(alpha)) {
     alpha <- lower[1] + 0.2 * (upper[1] - lower[1]) / m
@@ -1017,7 +1011,6 @@ initstate <- function(y, trendtype, seasontype) {
   return(c(l0, b0, init.seas))
 }
 
-
 lik <- function(par, y, nstate, errortype, trendtype, seasontype, damped, par.noopt, lowerb, upperb,
                 opt.crit, nmse, bounds, m, pnames, pnames2) {
 
@@ -1163,7 +1156,6 @@ print.ets <- function(x, ...) {
   #    cat(round(x$bic,4))
 }
 
-
 pegelsresid.C <- function(y, m, init.state, errortype, trendtype, seasontype, damped, alpha, beta, gamma, phi, nmse) {
   n <- length(y)
   p <- length(init.state)
@@ -1262,7 +1254,6 @@ admissible <- function(alpha, beta, gamma, phi, m) {
 
 ### PLOT COMPONENTS
 
-
 #' Plot components from ETS model
 #'
 #' Produces a plot of the level, slope and seasonal components from an ETS
@@ -1355,6 +1346,26 @@ fitted.ets <- function(object, h=1, ...) {
   }
 }
 
+#' @export
+hfitted.ets <- function(object, h=1, ...) {
+  n <- length(object$x)
+  out <- rep(NA_real_, n)
+  for(i in seq_len(n-h+1)) {
+    out[i+h-1] <- .C(
+      "etsforecast",
+      as.double(object$states[i, ]),
+      as.integer(object$m),
+      as.integer(switch(object$components[2], "N" = 0, "A" = 1, "M" = 2)),
+      as.integer(switch(object$components[3], "N" = 0, "A" = 1, "M" = 2)),
+      as.double(ifelse(object$components[4] == "FALSE", 1, object$par["phi"])),
+      as.integer(h),
+      as.double(numeric(h)),
+      PACKAGE = "forecast"
+    )[[7]][h]
+  }
+  out
+}
+
 #' @export
 logLik.ets <- function(object, ...) {
   structure(object$loglik, df = length(object$par) + 1, class = "logLik")
@@ -1366,7 +1377,6 @@ nobs.ets <- function(object, ...) {
 }
 
 
-
 #' Is an object a particular model type?
 #'
 #' Returns true if the model object is of a particular type
