@@ -100,11 +100,11 @@ tsCV <- function(y, forecastfunction, h=1, window=NULL, xreg=NULL, initial=0, ..
         start = i+1,
         end = i+h)
       fc <- try(suppressWarnings(
-        forecastfunction(y_subset, h = h, xreg = xreg_subset, newxreg=xreg_future)
+        forecastfunction(y_subset, h = h, xreg = xreg_subset, newxreg=xreg_future, ...)
         ), silent = TRUE)
     }
     if (!is.element("try-error", class(fc))) {
-      e[i, ] <- y[i + (1:h)] - fc$mean
+      e[i, ] <- y[i + seq(h)] - fc$mean[seq(h)]
     }
   }
   if (h == 1) {
@@ -119,7 +119,6 @@ tsCV <- function(y, forecastfunction, h=1, window=NULL, xreg=NULL, initial=0, ..
 # By Gabriel Caceres
 ## Note arguments to pass must be named
 
-
 #' k-fold Cross-Validation applied to an autoregressive model
 #'
 #' \code{CVar} computes the errors obtained by applying an autoregressive
